Summary: Realtime IRQ thread system tuning.
Name: rtirq
Version: 20120505
Release: 1%{?dist}
License: GPL
Group: System Environment/Base         
Source0: %{name}-%{version}.tar.gz
# add configuration option for a minimum priority in rtirq script
Patch0: rtirq-minprio.patch
# sources for udev and power management additions
Source1: rtirq-udev
Source2: rtirq-udev-rules
Source3: rtirq-power
# patch to add udev options to rtirq configuration
Patch1: rtirq-udevprio.patch
URL: http://www.rncbc.org/jack/
Packager: rncbc
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Vendor: Planet CCRMA
Distribution: Planet CCRMA

Requires: /bin/sh
Requires: /usr/bin/chrt
Requires(post,preun): /sbin/chkconfig

%description
Startup scripts for tunning the realtime scheduling policy and priority
of relevant IRQ service threads, featured for a realtime-preempt enabled
kernel configuration. 

%prep
%setup -q
%patch0 -p0
%patch1 -p0

%build

%install
%{__rm} -rf %{buildroot}
%{__install} -D rtirq.sh   -m 0755 %{buildroot}%{_sysconfdir}/rc.d/init.d/rtirq
%{__install} -D rtirq.conf -m 0644 %{buildroot}%{_sysconfdir}/sysconfig/rtirq

# fix order of interrupts, tac was reversing the priority of the soundcards
%{__perl} -p -i -e "s/\| tac//g" %{buildroot}%{_sysconfdir}/rc.d/init.d/rtirq

# start rtirq after the alsasound startup script (starts at 87)
%{__perl} -p -i -e "s|35 81 19|35 88 19|g" %{buildroot}%{_sysconfdir}/rc.d/init.d/rtirq

# priorities:
#   70 .. 65: rtirq irq processes (rtc snd i8042)
#   69: rtirq-udev irq processes
#   60: jackd
#   55: jackd client threads
#   50: other irq processes

# high priority is 70 instead of 90 (in Fedora 17+)
%{__perl} -p -i -e "s|RTIRQ_PRIO_HIGH=90|RTIRQ_PRIO_HIGH=70|g" %{buildroot}%{_sysconfdir}/sysconfig/rtirq
# low priority is 65, 5 above Jack highest priority thread
%{__perl} -p -i -e "s|RTIRQ_PRIO_LOW=51|RTIRQ_PRIO_LOW=65|g" %{buildroot}%{_sysconfdir}/sysconfig/rtirq
# priority decrement now 1 instead of 5, no need to leave vacant priorities
%{__perl} -p -i -e "s|RTIRQ_PRIO_DECR=5|RTIRQ_PRIO_DECR=1|g" %{buildroot}%{_sysconfdir}/sysconfig/rtirq
# remove usb from list of cards in configuration, this is now handled through udev rules
%{__perl} -p -i -e "s|rtc snd usb i8042|rtc snd i8042|g" %{buildroot}%{_sysconfdir}/sysconfig/rtirq
# adjust priority for udev changes, one less than the highest priority
# rtc usually takes the highest so let's be lower than that
%{__perl} -p -i -e "s|RTIRQ_PRIO_UDEV=85|RTIRQ_PRIO_UDEV=69|g" %{buildroot}%{_sysconfdir}/sysconfig/rtirq

# install udev and power files
%{__install} -D %{SOURCE2} -m 0644 %{buildroot}%{_sysconfdir}/udev/rules.d/95-rtirq.rules
%{__install} -D %{SOURCE1} -m 0755 %{buildroot}%{_bindir}/rtirq-udev
%{__install} -D %{SOURCE3} -m 0755 %{buildroot}%{_sysconfdir}/pm/sleep.d/05-rtirq

%post
# only run on install, not upgrade
if [ "$1" = "1" ]; then
    /sbin/chkconfig --add rtirq
#   /sbin/chkconfig rtirq on
fi
if [ -L /etc/rc.d/rc5.d/S81rtirq ] ; then
    # update startup to new priority
    /sbin/chkconfig --del rtirq
    /sbin/chkconfig --add rtirq
fi

%preun
# only run if this is the last instance to be removed
if [ "$1" = "0" ]; then
    /sbin/chkconfig rtirq off
    /sbin/chkconfig --del rtirq
fi

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/sysconfig/rtirq
%{_sysconfdir}/rc.d/init.d/rtirq
# udev and power management
%{_sysconfdir}/udev/rules.d/95-rtirq.rules
%{_sysconfdir}/pm/sleep.d/05-rtirq
%{_bindir}/rtirq-udev

%changelog
* Tue May 29 2012 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20120505-1
- udpate to 20120505
- add rtirq patch for minimum priority (nando@ccrma)
- tweak priorities for new Fedora allowed rt priorities (max priority for
  jack users is 70 in fc17+, jackd priority is 60)
- add udev rule, power management rule, udev script and patch to add udev
  and default priorities to rtirq configuration file (nando@ccrma)
- tweak udev priority to be the max priority

* Fri May  4 2012 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20120504-2
- update to 20120504, proper handling of pci soundcards on 3.2.x
- add patch to fix handling of soundcards on 3.2

* Fri Oct  7 2011 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20111007-1
- update to 20111007, has better logic for shared interrupts

* Tue May 31 2011 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20090920-1
- changed schedutils requirement to /usr/bin/chrt, fc15 no longer has it

* Mon Oct 26 2009 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20090920-1
- updated to latest version that works with 2.6.31.* rt kernels

* Thu Jan 11 2007 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20070101-1
- updated to 20070101, works with latest versions of the realtime
  preempt patch
- fix order of interrupts (was reversing the priority of the soundcards)

* Tue Aug 29 2006 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20060819-1
- updated to 20060819 (fixes errors on PREEMPT_DESKTOP kernels)

* Wed Apr  5 2006 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20060218-1
- updated to 20060218

* Mon Jun 20 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20050620-1
- updated to 20050620

* Thu Apr 14 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20050414-1
- Rui added support for unthreading rtc and snd interrupts

* Fri Apr  8 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20050408-1
- small fixes from Rui, new tarball

* Wed Apr  6 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20050407-1
- new tarball from Rui with dup irqs fix incorporated

* Wed Apr  6 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20050406-1
- updated to new tarball
- added patch to avoid irq's used by several devices to end up lower
  in priority, helps maintain the soundcard at the proper irq priority
- changed default high priority
- with both changes the soundcard priority should be 70...63

* Mon Mar 21 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20041118-2
- start rtirq after alsasound, add post script to check priority
  and readd rtirq if needed

* Thu Dec 23 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 20041118-1
- initial Planet CCRMA build
- do not rearrange interrupts on package install, seems safer to me,
  of course if there are problems this merely delays them till the 
  next reboot or when the user executes the script :-)

* Thu Nov 12 2004 Rui Nuno Capela <rncbc@users.sourceforge.net>
- Bumped to 20041112 version.

* Thu Nov 8 2004 Rui Nuno Capela <rncbc@users.sourceforge.net>
- Update for the new 20041108 version.

* Thu Nov 4 2004 Rui Nuno Capela <rncbc@users.sourceforge.net>
- Created initial rtirq.spec

